# Generated by Django 3.0.5 on 2020-04-06 13:13

import bitfield.models
from django.db import migrations, models
import image_assets.validators
from image_assets import defaults


class Migration(migrations.Migration):
    dependencies = [
        ('image_assets', '0006_migrate_formats'),
    ]
    operations = []
    if defaults.ASSET_TYPE_MODEL == 'image_assets.AssetType':
        operations.extend([
            migrations.RemoveField(
                model_name='assettype',
                name='format',
            ),
            migrations.AlterField(
                model_name='asset',
                name='image',
                field=models.ImageField(upload_to='', validators=[
                    image_assets.validators.AssetValidator()],
                                        verbose_name='Image'),
            ),
            migrations.AlterField(
                model_name='assettype',
                name='formats',
                field=bitfield.models.BitField(
                    (('jpeg', 'JPEG'), ('png', 'PNG')), default=0),
            ),
        ])



# Generated by Django 3.0.5 on 2020-04-02 09:42

from django.db import migrations, models
import django.db.models.deletion

from image_assets import defaults


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('image_assets', '0003_auto_20200402_0915'),
    ]

    operations = []
    if defaults.DELETED_ASSET_MODEL == 'image_assets.DeletedAsset':

        operations.extend([
            migrations.AlterField(
                model_name='deletedasset',
                name='asset_type',
                field=models.ForeignKey(
                    on_delete=django.db.models.deletion.CASCADE,
                    to='image_assets.AssetType',
                    verbose_name='Asset Type'),
            ),
            migrations.AlterField(
                model_name='deletedasset',
                name='content_type',
                field=models.ForeignKey(
                    on_delete=django.db.models.deletion.CASCADE,
                    to='contenttypes.ContentType',
                    verbose_name='Content Type'),
            ),
            migrations.AlterField(
                model_name='deletedasset',
                name='image',
                field=models.ImageField(upload_to='', verbose_name='Image'),
            ),
            migrations.AlterField(
                model_name='deletedasset',
                name='object_id',
                field=models.IntegerField(verbose_name='Object ID'),
            ),
        ])


# Generated by Django 3.0.4 on 2020-03-19 15:14

from django.db import migrations, models
import django.db.models.deletion
import image_assets.models
from image_assets import defaults


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = []
    if defaults.ASSET_TYPE_MODEL == 'image_assets.AssetType':
        operations.append(
            migrations.CreateModel(
                name='AssetType',
                fields=[
                    ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                    ('slug', models.SlugField(unique=True)),
                    ('format', models.CharField(choices=[('jpeg', 'JPEG'), ('png', 'PNG')], max_length=4, verbose_name='Image Format')),
                    ('min_width', models.IntegerField(default=0, verbose_name='Min Width')),
                    ('min_height', models.IntegerField(default=0, verbose_name='Min Height')),
                    ('aspect', models.FloatField(default=0, verbose_name='Aspect')),
                    ('accuracy', models.FloatField(default=0.01, verbose_name='Aspect accuracy')),
                    ('max_size', models.IntegerField(default=0, verbose_name='Max file size')),
                    ('allowed_for', models.ManyToManyField(blank=True, related_name='allowed_asset_types', related_query_name='allowed_asset_types', to='contenttypes.ContentType')),
                    ('required_for', models.ManyToManyField(blank=True, related_name='required_asset_types', related_query_name='required_asset_types', to='contenttypes.ContentType')),
                ],
                options={
                    'abstract': False,
                },
            ))
        if defaults.ASSET_MODEL == 'image_assets.Asset':
            operations.append(
                migrations.CreateModel(
                    name='Asset',
                    fields=[
                        ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                        ('image', models.ImageField(upload_to='', validators=[])),
                        ('active', models.BooleanField(default=True)),
                        ('object_id', models.IntegerField()),
                        ('asset_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=defaults.ASSET_TYPE_MODEL)),
                        ('content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType')),
                    ],
                    options={
                        'abstract':  False,
                    },
                ))
        if defaults.DELETED_ASSET_MODEL == 'image_assets.DeletedAsset':
            operations.append(
                migrations.CreateModel(
                    name='DeletedAsset',
                    fields=[
                        ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                        ('image', models.ImageField(upload_to='')),
                        ('object_id', models.IntegerField()),
                        ('asset_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=defaults.ASSET_TYPE_MODEL)),
                        ('content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType')),
                    ],
                    options={
                        'abstract': defaults.DELETED_ASSET_MODEL != 'image_assets.DeletedAsset',
                        'unique_together': {('content_type', 'object_id')},
                    },
                ))
